.. currentmodule:: skrub

.. _generating_a_report_ref:

Generating an HTML report
=========================

.. autosummary::
   :toctree: generated/
   :template: class.rst
   :nosignatures:

   TableReport
